@@ -439,7 +439,12 @@ int main(int argc, char* argv[])
 
         /// 実行 ///
         if(buf == NULL) {
-            break;
+            if(saphire_job_num() > 0) {
+                fprintf(stderr,"\njobs exist\n");
+            }
+            else {
+                break;
+            }
         }
         else if(*buf) {
             saphire_set_signal();
